@@ -1,10 +1,14 @@
 from pydantic import BaseModel
 from typing import Optional
 
+
 class TargetApp(BaseModel):
     app: str
-    version: Optional[str] = None
-    branch: Optional[str] = None
+    version: Optional[str] = "_"
+    branch: Optional[str] = "_"
+
+    def to_slashed_string(self):
+        return f"{self.app}/{self.version}/{self.branch}"
 
     @staticmethod
     def from_unique_slashed_string(slashed_string: str):
@@ -14,4 +18,6 @@ class TargetApp(BaseModel):
         elif len(target) == 2:
             return TargetApp(app=target[0], version=target[1], branch="_")
         elif len(target) == 1:
-            return TargetApp(app=target[0], version="_", branch="_")
\ No newline at end of file
+            return TargetApp(app=target[0], version="_", branch="_")
+
+
